
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.11'
version = '1.2.11'
full_version = '1.2.11'
git_revision = '55fe6279228d47dde0db6dcffb9c947f51cefc58'
release = True

if not release:
    version = full_version
    short_version += ".dev"
